@@ -30,13 +30,19 @@ manager::manager()
     mceInterface = new QDBusInterface(MCE_SERVICE, MCE_REQUEST_PATH,
                                       MCE_REQUEST_IF, connection, this);
 
-//    MyProximitySensor *prx = new MyProximitySensor();
-//    QObject::connect(prx, SIGNAL(sensorOpen()), this, SLOT(printTime()));
+    QDBusMessage msg = QDBusMessage::createMethodCall(
+            "proximityd.method.change", // --dest
+            "/proximityd/method/change", // destination object path
+            "proximityd.method.change", // message name (w/o method)
+            "Change" // method
+        );
+     msg << QString("turnOn");  // number hidden in posting
+     msg << getpid();
+     QDBusMessage reply = QDBusConnection::sessionBus().call(msg);
+     qDebug()<<reply;
 
-    timerCheck = new QTimer(this);
-    connect(timerCheck, SIGNAL(timeout()), this, SLOT(checkProximity()));
-    timerCheck->start(100);
-    connect(this, SIGNAL(sensorOpen()), this, SLOT(printTime()));
+    QDBusConnection sessionConnection = QDBusConnection::sessionBus();
+    sessionConnection.connect("", "/proximityd/signal/state", "proximityd.signal.state", "changed", this, SLOT(printTime(QString)));
 
     timerOff = new QTimer(this);
     connect(timerOff, SIGNAL(timeout()), this, SLOT(off()));
@@ -49,30 +55,44 @@ manager::manager()
     //printTime("d");
 }
 
+manager::~manager(){
+    QDBusMessage msg = QDBusMessage::createMethodCall(
+            "proximityd.method.change", // --dest
+            "/proximityd/method/change", // destination object path
+            "proximityd.method.change", // message name (w/o method)
+            "Change" // method
+        );
+     msg << QString("turnOff");  // number hidden in posting
+     msg << getpid();
+     QDBusMessage reply = QDBusConnection::sessionBus().call(msg);
+     qDebug()<<reply;
+}
+
 void manager::controlPolling(QDBusMessage& reply){
     QString status = reply.arguments().value(0).value<QString>();
     if (status == MCE_TK_LOCKED) timerCheck->start(); else timerCheck->stop();
 }
 
-void manager::printTime(){
-    const QDBusMessage& reply = mceInterface->call(MCE_DISPLAY_STATUS_GET);
-    QString status = reply.arguments().value(0).value<QString>();
-
-    if (status == MCE_DISPLAY_OFF_STRING){
+void manager::printTime(QString state){
+    qDebug("stateChanged");
+    if (checkIfLockedAndBlank()&&state=="open"){
           QProcess::startDetached( "/opt/timenowd/bin/shcript", QStringList() << " " );
           sleep(500);
           QDateTime now = QDateTime::currentDateTime();
           QFile file("/sys/class/graphics/fb0/rotate");
-          int x = 35, s = 14;
+          int x = 35, s = 14, sdate = 3, xdate = -300;
           if ( file.open(QIODevice::ReadOnly) ) {
           // file opened successfully
                   QTextStream t( &file );        // use a text stream
                   if ( t.readLine().compare("3", Qt::CaseSensitive) == 0 ) {
                       x = 0;
                       s = 10;
+                      sdate = 2;
+                      xdate = -100;
                   }
           }
-            QProcess::startDetached( "/usr/bin/text2screen", QStringList() << "-t " + now.toString("HH:mm") << "-s "+ QString::number(s) << "-T 0xFFFFFF" << "-B 0x000000" << "-x "+ QString::number(x) << "-y 0" );
+            QProcess::startDetached( "/usr/bin/text2screen", QStringList() << "-t " + now.toString("HH:mm") << "-s "+ QString::number(s) << "-T 0xFFFFFF" << "-B 0x000000" << "-H center" << "-y 0" );
+            QProcess::startDetached( "/usr/bin/text2screen", QStringList() << "-t " + now.toString("dddd dd/MM/yyyy") << "-s "+ QString::number(sdate) << "-T 0xFFFFFF" << "-B 0x000000" << "-x "+QString::number(xdate) << "-y 300" );
 //          printApixel();
 //          timer->start(60000);
           timerOff->start(6000);
@@ -84,10 +104,7 @@ void manager::printTime(){
 }
 
 void manager::off(){
-    const QDBusMessage& reply = mceInterface->call(MCE_DISPLAY_STATUS_GET);
-    QString status = reply.arguments().value(0).value<QString>();
-
-    if (status == MCE_DISPLAY_OFF_STRING){
+    if (checkIfLockedAndBlank()){
         QProcess::startDetached( "/opt/timenowd/bin/shcriptoff", QStringList() << " " );
     }
 }
@@ -188,6 +205,18 @@ void manager::printApixel(){
 
 }
 
+bool manager::checkIfLockedAndBlank(){
+    const QDBusMessage& reply = mceInterface->call(MCE_DISPLAY_STATUS_GET);
+    QString display = reply.arguments().value(0).value<QString>();
+
+    const QDBusMessage& reply2 = mceInterface->call(MCE_TKLOCK_MODE_GET);
+    QString locked = reply2.arguments().value(0).value<QString>();
+
+    if (display == MCE_DISPLAY_OFF_STRING && locked == MCE_TK_LOCKED){
+        return true;
+    } else return false;
+}
+
 
 void manager::sleep(int ms)
 {
